@@ -1,17 +1,16 @@
 use async_std::task::sleep;
 use futures::join;
 
-use std::fmt::Write;
 use std::time::Duration;
 
 #[async_std::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let output = minus::Pager::new().finish();
+    let output = minus::Pager::new().unwrap().finish();
 
     let increment = async {
         for i in 0..=30_u32 {
             let mut output = output.lock().await;
-            writeln!(output.lines, "{}", i)?;
+            output.push_str(format!("{}\n", i));
             drop(output);
             sleep(Duration::from_millis(100)).await;
         }
